==> php54-owncloud-8.0.3.tgz: share/owncloud/apps/files_sharing/l10n/it.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "La condivisione tra server non è abilitata su questo server",
    "The mountpoint name contains invalid characters." : "Il nome del punto di mount contiene caratteri non validi.",
    "Invalid or untrusted SSL certificate" : "Certificato SSL non valido o non attendibile",
    "Could not authenticate to remote share, password might be wrong" : "Impossibile autenticarsi sulla condivisione remota, la password potrebbe essere errata",
    "Storage not valid" : "Archiviazione non valida",
    "Couldn't add remote share" : "Impossibile aggiungere la condivisione remota",
    "Shared with you" : "Condivisi con te",
    "Shared with others" : "Condivisi con altri",
    "Shared by link" : "Condivisi tramite collegamento",
    "Nothing shared with you yet" : "Non è stato condiviso ancora niente con te",
    "Files and folders others share with you will show up here" : "I file e le cartelle che altri condividono con te saranno mostrati qui",
    "Nothing shared yet" : "Ancora nessuna condivisione",
    "Files and folders you share will show up here" : "I file e le cartelle che condividi saranno mostrati qui",
    "No shared links" : "Nessun collegamento condiviso",
    "Files and folders you share by link will show up here" : "I file e le cartelle che condividi tramite collegamento saranno mostrati qui",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Vuoi aggiungere la condivisione remota {name} da {owner}@{remote}?",
    "Remote share" : "Condivisione remota",
    "Remote share password" : "Password della condivisione remota",
    "Cancel" : "Annulla",
    "Add remote share" : "Aggiungi condivisione remota",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nessuna installazione di ownCloud (7 o superiore) trovata su {remote}",
    "Invalid ownCloud url" : "URL di ownCloud non valido",
    "Share" : "Condividi",
    "Shared by" : "Condiviso da",
    "A file or folder was shared from <strong>another server</strong>" : "Un file o una cartella è stato condiviso da <strong>un altro server</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Un file condiviso pubblicamente o una cartella è stato <strong>scaricato</strong>",
    "You received a new remote share from %s" : "Hai ricevuto una nuova condivisione remota da %s",
    "%1$s accepted remote share %2$s" : "%1$s ha accettato la condivisione remota %2$s",
    "%1$s declined remote share %2$s" : "%1$s ha rifiutato la condivisione remota %2$s",
    "%1$s unshared %2$s from you" : "%1$s ha rimosso la condivisione %2$s con te",
    "Public shared folder %1$s was downloaded" : "La cartella condivisa pubblicamente %1$s è stata scaricata",
    "Public shared file %1$s was downloaded" : "Il file condiviso pubblicamente %1$s è stato scaricato",
    "This share is password-protected" : "Questa condivione è protetta da password",
    "The password is wrong. Try again." : "La password è errata. Prova ancora.",
    "Password" : "Password",
    "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
    "Name" : "Nome",
    "Share time" : "Tempo di condivisione",
    "Sorry, this link doesn’t seem to work anymore." : "Spiacenti, questo collegamento sembra non essere più attivo.",
    "Reasons might be:" : "I motivi potrebbero essere:",
    "the item was removed" : "l'elemento è stato rimosso",
    "the link expired" : "il collegamento è scaduto",
    "sharing is disabled" : "la condivisione è disabilitata",
    "For more info, please ask the person who sent this link." : "Per ulteriori informazioni, chiedi alla persona che ti ha inviato il collegamento.",
    "Add to your ownCloud" : "Aggiungi al tuo ownCloud",
    "Download" : "Scarica",
    "Download %s" : "Scarica %s",
    "Direct link" : "Collegamento diretto",
    "Federated Cloud Sharing" : "Condivisione cloud federata",
    "Allow users on this server to send shares to other servers" : "Consenti agli utenti su questo server di inviare condivisioni ad altri server",
    "Allow users on this server to receive shares from other servers" : "Consenti agli utenti su questo server di ricevere condivisioni da altri server"
},
"nplurals=2; plural=(n != 1);");

==> php54-owncloud-8.1.0.tgz: share/owncloud/apps/files_sharing/l10n/it.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "La condivisione tra server non è abilitata su questo server",
    "The mountpoint name contains invalid characters." : "Il nome del punto di mount contiene caratteri non validi.",
    "Invalid or untrusted SSL certificate" : "Certificato SSL non valido o non attendibile",
    "Could not authenticate to remote share, password might be wrong" : "Impossibile autenticarsi sulla condivisione remota, la password potrebbe essere errata",
    "Storage not valid" : "Archiviazione non valida",
    "Couldn't add remote share" : "Impossibile aggiungere la condivisione remota",
    "Shared with you" : "Condivisi con te",
    "Shared with others" : "Condivisi con altri",
    "Shared by link" : "Condivisi tramite collegamento",
    "Nothing shared with you yet" : "Non è stato condiviso ancora niente con te",
    "Files and folders others share with you will show up here" : "I file e le cartelle che altri condividono con te saranno mostrati qui",
    "Nothing shared yet" : "Ancora nessuna condivisione",
    "Files and folders you share will show up here" : "I file e le cartelle che condividi saranno mostrati qui",
    "No shared links" : "Nessun collegamento condiviso",
    "Files and folders you share by link will show up here" : "I file e le cartelle che condividi tramite collegamento saranno mostrati qui",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Vuoi aggiungere la condivisione remota {name} da {owner}@{remote}?",
    "Remote share" : "Condivisione remota",
    "Remote share password" : "Password della condivisione remota",
    "Cancel" : "Annulla",
    "Add remote share" : "Aggiungi condivisione remota",
    "You can upload into this folder" : "Puoi caricare in questa cartella",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nessuna installazione di ownCloud (7 o superiore) trovata su {remote}",
    "Invalid ownCloud url" : "URL di ownCloud non valido",
    "Share" : "Condividi",
    "Shared by" : "Condiviso da",
    "A file or folder has been <strong>shared</strong>" : "Un file o una cartella è stato <strong>condiviso</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Un file o una cartella è stato condiviso da <strong>un altro server</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Un file condiviso pubblicamente o una cartella è stato <strong>scaricato</strong>",
    "You received a new remote share from %s" : "Hai ricevuto una nuova condivisione remota da %s",
    "%1$s accepted remote share %2$s" : "%1$s ha accettato la condivisione remota %2$s",
    "%1$s declined remote share %2$s" : "%1$s ha rifiutato la condivisione remota %2$s",
    "%1$s unshared %2$s from you" : "%1$s ha rimosso la condivisione %2$s con te",
    "Public shared folder %1$s was downloaded" : "La cartella condivisa pubblicamente %1$s è stata scaricata",
    "Public shared file %1$s was downloaded" : "Il file condiviso pubblicamente %1$s è stato scaricato",
    "You shared %1$s with %2$s" : "Hai condiviso %1$s con %2$s",
    "You shared %1$s with group %2$s" : "Hai condiviso %1$s con il gruppo %2$s",
    "%2$s shared %1$s with you" : "%2$s ha condiviso %1$s con te",
    "You shared %1$s via link" : "Hai condiviso %1$s tramite collegamento",
    "Shares" : "Condivisioni",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Condividi con me attraverso il mio ID di cloud federata #ownCloud, vedi %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Condividi con me attraverso il mio ID di cloud federata #ownCloud",
    "This share is password-protected" : "Questa condivione è protetta da password",
    "The password is wrong. Try again." : "La password è errata. Prova ancora.",
    "Password" : "Password",
    "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
    "Name" : "Nome",
    "Share time" : "Tempo di condivisione",
    "Sorry, this link doesn’t seem to work anymore." : "Spiacenti, questo collegamento sembra non essere più attivo.",
    "Reasons might be:" : "I motivi potrebbero essere:",
    "the item was removed" : "l'elemento è stato rimosso",
    "the link expired" : "il collegamento è scaduto",
    "sharing is disabled" : "la condivisione è disabilitata",
    "For more info, please ask the person who sent this link." : "Per ulteriori informazioni, chiedi alla persona che ti ha inviato il collegamento.",
    "Add to your ownCloud" : "Aggiungi al tuo ownCloud",
    "Download" : "Scarica",
    "Download %s" : "Scarica %s",
    "Direct link" : "Collegamento diretto",
    "Federated Cloud Sharing" : "Condivisione cloud federata",
    "Open documentation" : "Apri la documentazione",
    "Allow users on this server to send shares to other servers" : "Consenti agli utenti su questo server di inviare condivisioni ad altri server",
    "Allow users on this server to receive shares from other servers" : "Consenti agli utenti su questo server di ricevere condivisioni da altri server",
    "Federated Cloud" : "Cloud federata",
    "Your Federated Cloud ID:" : "Il tuo ID di cloud federata:",
    "Share it:" : "Condividilo:",
    "Add it to your website:" : "Aggiungilo al tuo sito web:",
    "Share with me via ownCloud" : "Condividi con me tramite ownCloud",
    "HTML Code:" : "Codice HTML:"
},
"nplurals=2; plural=(n != 1);");
